# Overview
*poweretl* is library to support database, data-warehouse, data-lakehouse python projects. *poweretl-utils* is independent package for not only etl tasks.

Read more about library on git-hub: [poweretl](https://github.com/plazacraft/poweretl)

# Features
| Class                                     | Features
| ----------------------------------------- | --------------------------------------------------------- |
| poweretl.utils.file.FileCommandSplitter   |   |
| poweretl.utils.file.FileMerger            |   |
| poweretl.utils.file.MultiFileReader       |   |
| poweretl.utils.text.TokensReplacer        |   |



